tokenizer\_tools.tagset.offset package
======================================

Submodules
----------

tokenizer\_tools.tagset.offset.corpus module
--------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.corpus
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.corpus\_set module
-------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.corpus_set
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.exceptions module
------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.sequence module
----------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.sequence
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.span module
------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.span
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.span\_set module
-----------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.span_set
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.tagset.offset
   :members:
   :undoc-members:
   :show-inheritance:
